@@ -15,32 +15,32 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from .type_defs import (
-    AddAvailabilityZonesOutputResponseTypeDef,
-    ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef,
-    AttachLoadBalancerToSubnetsOutputResponseTypeDef,
-    ConfigureHealthCheckOutputResponseTypeDef,
-    CreateAccessPointOutputResponseTypeDef,
-    DeregisterEndPointsOutputResponseTypeDef,
-    DescribeAccessPointsOutputResponseTypeDef,
-    DescribeAccountLimitsOutputResponseTypeDef,
-    DescribeEndPointStateOutputResponseTypeDef,
-    DescribeLoadBalancerAttributesOutputResponseTypeDef,
-    DescribeLoadBalancerPoliciesOutputResponseTypeDef,
-    DescribeLoadBalancerPolicyTypesOutputResponseTypeDef,
-    DescribeTagsOutputResponseTypeDef,
-    DetachLoadBalancerFromSubnetsOutputResponseTypeDef,
+    AddAvailabilityZonesOutputTypeDef,
+    ApplySecurityGroupsToLoadBalancerOutputTypeDef,
+    AttachLoadBalancerToSubnetsOutputTypeDef,
+    ConfigureHealthCheckOutputTypeDef,
+    CreateAccessPointOutputTypeDef,
+    DeregisterEndPointsOutputTypeDef,
+    DescribeAccessPointsOutputTypeDef,
+    DescribeAccountLimitsOutputTypeDef,
+    DescribeEndPointStateOutputTypeDef,
+    DescribeLoadBalancerAttributesOutputTypeDef,
+    DescribeLoadBalancerPoliciesOutputTypeDef,
+    DescribeLoadBalancerPolicyTypesOutputTypeDef,
+    DescribeTagsOutputTypeDef,
+    DetachLoadBalancerFromSubnetsOutputTypeDef,
     HealthCheckTypeDef,
     InstanceTypeDef,
     ListenerTypeDef,
     LoadBalancerAttributesTypeDef,
-    ModifyLoadBalancerAttributesOutputResponseTypeDef,
+    ModifyLoadBalancerAttributesOutputTypeDef,
     PolicyAttributeTypeDef,
-    RegisterEndPointsOutputResponseTypeDef,
-    RemoveAvailabilityZonesOutputResponseTypeDef,
+    RegisterEndPointsOutputTypeDef,
+    RemoveAvailabilityZonesOutputTypeDef,
     TagKeyOnlyTypeDef,
     TagTypeDef,
 )
@@ -89,42 +89,47 @@ class Exceptions:
     UnsupportedProtocolException: Type[BotocoreClientError]
 
 
-class ElasticLoadBalancingClient:
+class ElasticLoadBalancingClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ElasticLoadBalancingClient exceptions.
+        """
 
     def add_tags(self, *, LoadBalancerNames: List[str], Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds the specified tags to the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#add_tags)
         """
 
     def apply_security_groups_to_load_balancer(
         self, *, LoadBalancerName: str, SecurityGroups: List[str]
-    ) -> ApplySecurityGroupsToLoadBalancerOutputResponseTypeDef:
+    ) -> ApplySecurityGroupsToLoadBalancerOutputTypeDef:
         """
         Associates one or more security groups with your load balancer in a virtual
         private cloud (VPC).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#apply_security_groups_to_load_balancer)
         """
 
     def attach_load_balancer_to_subnets(
         self, *, LoadBalancerName: str, Subnets: List[str]
-    ) -> AttachLoadBalancerToSubnetsOutputResponseTypeDef:
+    ) -> AttachLoadBalancerToSubnetsOutputTypeDef:
         """
         Adds one or more subnets to the set of configured subnets for the specified load
         balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#attach_load_balancer_to_subnets)
         """
 
@@ -132,18 +137,18 @@ class ElasticLoadBalancingClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#can_paginate)
         """
 
     def configure_health_check(
         self, *, LoadBalancerName: str, HealthCheck: "HealthCheckTypeDef"
-    ) -> ConfigureHealthCheckOutputResponseTypeDef:
+    ) -> ConfigureHealthCheckOutputTypeDef:
         """
         Specifies the health check settings to use when evaluating the health state of
         your EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#configure_health_check)
         """
 
@@ -154,7 +159,7 @@ class ElasticLoadBalancingClient:
         Generates a stickiness policy with sticky session lifetimes that follow that of
         an application-generated cookie.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_app_cookie_stickiness_policy)
         """
 
@@ -165,7 +170,7 @@ class ElasticLoadBalancingClient:
         Generates a stickiness policy with sticky session lifetimes controlled by the
         lifetime of the browser (user-agent) or a specified expiration period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_lb_cookie_stickiness_policy)
         """
 
@@ -179,11 +184,11 @@ class ElasticLoadBalancingClient:
         SecurityGroups: List[str] = None,
         Scheme: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateAccessPointOutputResponseTypeDef:
+    ) -> CreateAccessPointOutputTypeDef:
         """
         Creates a Classic Load Balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer)
         """
 
@@ -193,7 +198,7 @@ class ElasticLoadBalancingClient:
         """
         Creates one or more listeners for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_listeners)
         """
 
@@ -208,7 +213,7 @@ class ElasticLoadBalancingClient:
         """
         Creates a policy with the specified attributes for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_policy)
         """
 
@@ -216,7 +221,7 @@ class ElasticLoadBalancingClient:
         """
         Deletes the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer)
         """
 
@@ -226,7 +231,7 @@ class ElasticLoadBalancingClient:
         """
         Deletes the specified listeners from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_listeners)
         """
 
@@ -236,121 +241,121 @@ class ElasticLoadBalancingClient:
         """
         Deletes the specified policy from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_policy)
         """
 
     def deregister_instances_from_load_balancer(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
-    ) -> DeregisterEndPointsOutputResponseTypeDef:
+    ) -> DeregisterEndPointsOutputTypeDef:
         """
         Deregisters the specified instances from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#deregister_instances_from_load_balancer)
         """
 
     def describe_account_limits(
         self, *, Marker: str = None, PageSize: int = None
-    ) -> DescribeAccountLimitsOutputResponseTypeDef:
+    ) -> DescribeAccountLimitsOutputTypeDef:
         """
         Describes the current Elastic Load Balancing resource limits for your AWS
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_account_limits)
         """
 
     def describe_instance_health(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"] = None
-    ) -> DescribeEndPointStateOutputResponseTypeDef:
+    ) -> DescribeEndPointStateOutputTypeDef:
         """
         Describes the state of the specified instances with respect to the specified
         load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_instance_health)
         """
 
     def describe_load_balancer_attributes(
         self, *, LoadBalancerName: str
-    ) -> DescribeLoadBalancerAttributesOutputResponseTypeDef:
+    ) -> DescribeLoadBalancerAttributesOutputTypeDef:
         """
         Describes the attributes for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_attributes)
         """
 
     def describe_load_balancer_policies(
         self, *, LoadBalancerName: str = None, PolicyNames: List[str] = None
-    ) -> DescribeLoadBalancerPoliciesOutputResponseTypeDef:
+    ) -> DescribeLoadBalancerPoliciesOutputTypeDef:
         """
         Describes the specified policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policies)
         """
 
     def describe_load_balancer_policy_types(
         self, *, PolicyTypeNames: List[str] = None
-    ) -> DescribeLoadBalancerPolicyTypesOutputResponseTypeDef:
+    ) -> DescribeLoadBalancerPolicyTypesOutputTypeDef:
         """
         Describes the specified load balancer policy types or all load balancer policy
         types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policy_types)
         """
 
     def describe_load_balancers(
         self, *, LoadBalancerNames: List[str] = None, Marker: str = None, PageSize: int = None
-    ) -> DescribeAccessPointsOutputResponseTypeDef:
+    ) -> DescribeAccessPointsOutputTypeDef:
         """
         Describes the specified the load balancers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancers)
         """
 
-    def describe_tags(self, *, LoadBalancerNames: List[str]) -> DescribeTagsOutputResponseTypeDef:
+    def describe_tags(self, *, LoadBalancerNames: List[str]) -> DescribeTagsOutputTypeDef:
         """
         Describes the tags associated with the specified load balancers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_tags)
         """
 
     def detach_load_balancer_from_subnets(
         self, *, LoadBalancerName: str, Subnets: List[str]
-    ) -> DetachLoadBalancerFromSubnetsOutputResponseTypeDef:
+    ) -> DetachLoadBalancerFromSubnetsOutputTypeDef:
         """
         Removes the specified subnets from the set of configured subnets for the load
         balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#detach_load_balancer_from_subnets)
         """
 
     def disable_availability_zones_for_load_balancer(
         self, *, LoadBalancerName: str, AvailabilityZones: List[str]
-    ) -> RemoveAvailabilityZonesOutputResponseTypeDef:
+    ) -> RemoveAvailabilityZonesOutputTypeDef:
         """
         Removes the specified Availability Zones from the set of Availability Zones for
         the specified load balancer in EC2-Classic or a default VPC.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#disable_availability_zones_for_load_balancer)
         """
 
     def enable_availability_zones_for_load_balancer(
         self, *, LoadBalancerName: str, AvailabilityZones: List[str]
-    ) -> AddAvailabilityZonesOutputResponseTypeDef:
+    ) -> AddAvailabilityZonesOutputTypeDef:
         """
         Adds the specified Availability Zones to the set of Availability Zones for the
         specified load balancer in EC2-Classic or a default VPC.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#enable_availability_zones_for_load_balancer)
         """
 
@@ -364,27 +369,27 @@ class ElasticLoadBalancingClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#generate_presigned_url)
         """
 
     def modify_load_balancer_attributes(
         self, *, LoadBalancerName: str, LoadBalancerAttributes: "LoadBalancerAttributesTypeDef"
-    ) -> ModifyLoadBalancerAttributesOutputResponseTypeDef:
+    ) -> ModifyLoadBalancerAttributesOutputTypeDef:
         """
         Modifies the attributes of the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#modify_load_balancer_attributes)
         """
 
     def register_instances_with_load_balancer(
         self, *, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
-    ) -> RegisterEndPointsOutputResponseTypeDef:
+    ) -> RegisterEndPointsOutputTypeDef:
         """
         Adds the specified instances to the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#register_instances_with_load_balancer)
         """
 
@@ -394,7 +399,7 @@ class ElasticLoadBalancingClient:
         """
         Removes one or more tags from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#remove_tags)
         """
 
@@ -404,7 +409,7 @@ class ElasticLoadBalancingClient:
         """
         Sets the certificate that terminates the specified listener's SSL connections.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_listener_ssl_certificate)
         """
 
@@ -415,7 +420,7 @@ class ElasticLoadBalancingClient:
         Replaces the set of policies associated with the specified port on which the EC2
         instance is listening with a new set of policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_for_backend_server)
         """
 
@@ -426,7 +431,7 @@ class ElasticLoadBalancingClient:
         Replaces the current set of policies for the specified load balancer port with
         the specified set of policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_of_listener)
         """
 
@@ -435,7 +440,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_account_limits"]
     ) -> DescribeAccountLimitsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
         """
 
@@ -444,7 +449,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_load_balancers"]
     ) -> DescribeLoadBalancersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
         """
 
@@ -453,7 +458,7 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["any_instance_in_service"]
     ) -> AnyInstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
         """
 
@@ -462,13 +467,13 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["instance_deregistered"]
     ) -> InstanceDeregisteredWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
         """
