@@ -25,8 +25,8 @@ from typing import Iterator, List
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
-    DescribeAccessPointsOutputResponseTypeDef,
-    DescribeAccountLimitsOutputResponseTypeDef,
+    DescribeAccessPointsOutputTypeDef,
+    DescribeAccountLimitsOutputTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -35,22 +35,22 @@ __all__ = ("DescribeAccountLimitsPaginator", "DescribeLoadBalancersPaginator")
 
 class DescribeAccountLimitsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeAccountLimitsOutputResponseTypeDef]:
+    ) -> Iterator[DescribeAccountLimitsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
         """
 
 
 class DescribeLoadBalancersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
     """
 
@@ -59,8 +59,8 @@ class DescribeLoadBalancersPaginator(Boto3Paginator):
         *,
         LoadBalancerNames: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeAccessPointsOutputResponseTypeDef]:
+    ) -> Iterator[DescribeAccessPointsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.105/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
         """
